@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,20 +28,18 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __NACT_PREFS_H__
-#define __NACT_PREFS_H__
+#ifndef __NACT_IPREFS_H__
+#define __NACT_IPREFS_H__
 
-/*
- * NactIPrefs interface definition.
+/**
+ * SECTION: nact_iprefs
+ * @short_description: #NactIPrefs interface definition.
+ * @include: nact/nact-iprefs.h
  *
- * This interface may be implemented by all dialogs which wish take
- * benefit of preferences management.
+ * This interface cooperates with #NactWindow to manage preferences.
  */
 
-#include <glib-object.h>
-#include <gtk/gtk.h>
-
-#include "nact-window.h"
+#include "base-window.h"
 
 G_BEGIN_DECLS
 
@@ -50,38 +48,43 @@ G_BEGIN_DECLS
 #define NACT_IS_IPREFS( object )				( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_IPREFS_TYPE ))
 #define NACT_IPREFS_GET_INTERFACE( instance )	( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NACT_IPREFS_TYPE, NactIPrefsInterface ))
 
-typedef struct NactIPrefs NactIPrefs;
+typedef struct NactIPrefs                 NactIPrefs;
 
 typedef struct NactIPrefsInterfacePrivate NactIPrefsInterfacePrivate;
 
 typedef struct {
 	GTypeInterface              parent;
 	NactIPrefsInterfacePrivate *private;
-
-	/* api */
-	gchar * ( *get_iprefs_window_id )( NactWindow *window );
 }
 	NactIPrefsInterface;
 
-GType    nact_iprefs_get_type( void );
+#define IPREFS_EXPORT_ITEMS_FOLDER_URI			"export-folder-uri"
+#define IPREFS_EXPORT_FORMAT					"export-format"
+#define IPREFS_EXPORT_ASK_LAST_FORMAT			"export-ask-user-last-format"
 
-void     nact_iprefs_position_window( NactWindow *window );
-void     nact_iprefs_position_named_window( NactWindow *window, GtkWindow *toplevel, const gchar *name );
+#define IPREFS_EXPORT_FORMAT_DEFAULT			"GConfEntry"
 
-void     nact_iprefs_save_window_position( NactWindow *window );
-void     nact_iprefs_save_named_window_position( NactWindow *window, GtkWindow *toplevel, const gchar *name );
+#define IPREFS_IMPORT_ITEMS_FOLDER_URI			"import-folder-uri"
 
-gchar   *nact_iprefs_get_iconditions_folder_uri( NactWindow *window );
-void     nact_iprefs_save_iconditions_folder_uri( NactWindow *window, const gchar *uri );
+#define IPREFS_ASSIST_ESC_QUIT					"assistant-esc-quit"
+#define IPREFS_ASSIST_ESC_CONFIRM				"assistant-esc-confirm"
 
-gchar   *nact_iprefs_get_import_folder_uri( NactWindow *window );
-void     nact_iprefs_save_import_folder_uri( NactWindow *window, const gchar *uri );
+/* these are special export formats
+ */
+enum {
+	IPREFS_EXPORT_NO_EXPORT = 1,
+	IPREFS_EXPORT_FORMAT_GCONF_SCHEMA
+};
 
-gchar   *nact_iprefs_get_export_folder_uri( NactWindow *window );
-void     nact_iprefs_save_export_folder_uri( NactWindow *window, const gchar *uri );
+GType nact_iprefs_get_type( void );
 
-gint     nact_iprefs_get_int( NactWindow *window, const gchar *key );
-void     nact_iprefs_set_int( NactWindow *window, const gchar *key, gint value );
+GQuark nact_iprefs_get_export_format( const BaseWindow *window, const gchar *pref );
+void   nact_iprefs_set_export_format( const BaseWindow *window, const gchar *pref, GQuark format );
+
+void  nact_iprefs_migrate_key       ( const BaseWindow *window, const gchar *old_key, const gchar *new_key );
+
+void  nact_iprefs_write_bool        ( const BaseWindow *window, const gchar *key, gboolean value );
+void  nact_iprefs_write_string      ( const BaseWindow *window, const gchar *name, const gchar *value );
 
 G_END_DECLS
 
